"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SyntaxHighlighter = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
// Maintain a cache of loaded languages and themes
const languageCache = new Map();
const themeCache = new Map();

// Singleton highlighter instance
let highlighterInstance = null;
async function loadLanguage(lang) {
  if (languageCache.has(lang)) {
    return languageCache.get(lang);
  }
  try {
    const module = await (specifier => new Promise(r => r(specifier)).then(s => _interopRequireWildcard(require(s))))(`shiki/langs/${lang}.mjs`);
    languageCache.set(lang, module.default);
    return module.default;
  } catch {
    // Fallback to plaintext if language not found
    console.warn(`Language '${lang}' not found, falling back to plaintext`);
    return {
      name: 'plaintext',
      scopeName: 'source.plaintext',
      patterns: []
    };
  }
}
async function loadTheme(themeName) {
  if (themeCache.has(themeName)) {
    return themeCache.get(themeName);
  }
  try {
    const module = await (specifier => new Promise(r => r(specifier)).then(s => _interopRequireWildcard(require(s))))(`shiki/themes/${themeName}.mjs`);
    themeCache.set(themeName, module.default);
    return module.default;
  } catch {
    throw new Error(`Theme '${themeName}' not found`);
  }
}
async function getHighlighter() {
  if (!highlighterInstance) {
    highlighterInstance = await (0, _core.createHighlighterCore)({
      engine: (0, _engineJavascript.createJavaScriptRegexEngine)()
    });
  }
  return highlighterInstance;
}
const SyntaxHighlighter = ({
  children,
  language,
  theme,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [tokens, setTokens] = _react.default.useState([]);
  const [backgroundColor, setBackgroundColor] = _react.default.useState('#0d1117');
  const [loading, setLoading] = _react.default.useState(true);
  const [error, setError] = _react.default.useState(null);
  _react.default.useEffect(() => {
    const highlight = async () => {
      try {
        setLoading(true);

        // Load language and theme
        const [langData, themeData] = await Promise.all([loadLanguage(language), loadTheme(theme)]);

        // Get highlighter and load language/theme
        const highlighter = await getHighlighter();
        await highlighter.loadLanguage(langData);
        await highlighter.loadTheme(themeData);

        // Highlight the code
        const result = highlighter.codeToTokens(children, {
          lang: language,
          theme
        });
        setTokens(result.tokens);
        setBackgroundColor(result.bg || '#0d1117');
        setError(null);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to highlight code');
        console.error('Highlighting error:', err);
      } finally {
        setLoading(false);
      }
    };
    highlight();
  }, [children, language, theme]);
  const renderToken = (token, index) => {
    const style = {
      color: token.color || '#c9d1d9',
      ...(token.fontStyle === 1 && {
        fontStyle: 'italic'
      }),
      ...(token.fontStyle === 2 && {
        fontWeight: 'bold'
      })
    };
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: [textStyle, style],
      children: token.content
    }, `${token.offset}-${index}`);
  };
  const renderLine = (lineTokens, index) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: lineTokens.map((token, tokenIndex) => renderToken(token, tokenIndex))
  }, index);
  if (loading) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [{
        backgroundColor,
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [{
        backgroundColor,
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: {
          color: '#ff6b6b'
        },
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    style: [{
      backgroundColor
    }, scrollViewProps?.style],
    contentContainerStyle: [containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
};
exports.SyntaxHighlighter = SyntaxHighlighter;
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map